diff --git a/src/gulpfile.js b/src/gulpfile.js
index 8bb1c620..75f16816 100644
--- a/src/gulpfile.js
+++ b/src/gulpfile.js
@@ -165,7 +165,7 @@ gulp.task('bower-install', function(callback) {
});
});
-// Compile all JavaScript files of the Mibew Core
+// Compile all JavaScript files of the Mibew Messenger Core
gulp.task('js', function() {
return eventStream.merge(
getClientSideApp('default'),
@@ -380,8 +380,8 @@ gulp.task('prepare-release', function(callback) {
);
});
-// Prepares ready to use development version of Mibew without packing or
-// validating it.
+// Prepares ready to use development version of Mibew Messenger without packing
+// or validating it.
gulp.task('rebuild', function(callback) {
runSequence(
'clean',
diff --git a/src/mibew/.htaccess b/src/mibew/.htaccess
index 4d622c86..b460580c 100644
--- a/src/mibew/.htaccess
+++ b/src/mibew/.htaccess
@@ -46,9 +46,10 @@ Options +FollowSymLinks
- # There is no mod_rewrite in the system. For the root Mibew directory
- # index_fallback.php should be loaded first to activate old-fashioned URLs.
- # For all other directories index.php is just a directory index file.
+ # There is no mod_rewrite in the system. For the root Mibew Messenger
+ # directory index_fallback.php should be loaded first to activate
+ # old-fashioned URLs. For all other directories index.php is just a
+ # directory index file.
DirectoryIndex index_fallback.php index.php
diff --git a/src/mibew/configs/database_schema.yml b/src/mibew/configs/database_schema.yml
index d8b7c71e..72ea7568 100644
--- a/src/mibew/configs/database_schema.yml
+++ b/src/mibew/configs/database_schema.yml
@@ -72,7 +72,7 @@ thread:
useragent: "varchar(255)"
# Total count of user's messages related with the thread.
messagecount: "varchar(16)"
- # ID of the group at Mibew side related with the thread.
+ # ID of the group at Mibew Messenger side related with the thread.
groupid: "int references {opgroup}(groupid)"
# Contains "by thread" statistics
diff --git a/src/mibew/configs/default_config.yml b/src/mibew/configs/default_config.yml
index 76509e12..2471b237 100644
--- a/src/mibew/configs/default_config.yml
+++ b/src/mibew/configs/default_config.yml
@@ -1,5 +1,5 @@
-# IMPORTANT: Before install mibew copy this file to config.yml and fill it with
-# your own settings!
+# IMPORTANT: Before install Mibew Messenger copy this file to config.yml and
+# fill it with your own settings!
# MySQL Database parameters
@@ -13,7 +13,7 @@ database:
use_persistent_connection: false
# Mail
-## This value will be used as sender address in all e-mails Mibew send.
+## This value will be used as sender address in all e-mails Mibew Messenger send.
mailbox: mibew@yourdomain.com
## Mailer parameters
@@ -77,8 +77,8 @@ default_locale: en
# http://php.net/manual/en/timezones.php
timezone: ""
-# List of proxy's IP Mibew should trust. You should set this option if you use
-# Mibew with a load balancer or behind a proxy.
+# List of proxy's IP Mibew Messenger should trust. You should set this option
+# if you use Mibew Messenger with a load balancer or behind a proxy.
trusted_proxies: []
# Here is an example of what values this option can take:
# trusted_proxies:
diff --git a/src/mibew/js/source/chat_popup.js b/src/mibew/js/source/chat_popup.js
index bc6b1257..692931fd 100644
--- a/src/mibew/js/source/chat_popup.js
+++ b/src/mibew/js/source/chat_popup.js
@@ -17,7 +17,7 @@
*/
/**
- * @namespace Holds all Mibew functionality
+ * @namespace Holds all Mibew Messenger functionality
*/
var Mibew = Mibew || {};
diff --git a/src/mibew/js/source/mibewapi.js b/src/mibew/js/source/mibewapi.js
index d3cf61fc..c2d141b0 100644
--- a/src/mibew/js/source/mibewapi.js
+++ b/src/mibew/js/source/mibewapi.js
@@ -26,7 +26,7 @@
function MibewAPI(interaction) {
/**
- * Version of the MIBEW API protocol implemented by the object
+ * Version of the Mibew API protocol implemented by the object
*/
this.protocolVersion = "1.0";
diff --git a/src/mibew/js/source/widget.js b/src/mibew/js/source/widget.js
index 6955568d..ab4e7e38 100644
--- a/src/mibew/js/source/widget.js
+++ b/src/mibew/js/source/widget.js
@@ -17,7 +17,7 @@
*/
/**
- * @namespace Holds all Mibew functionality
+ * @namespace Holds all Mibew Messenger functionality
*/
var Mibew = Mibew || {};
diff --git a/src/mibew/libs/classes/Mibew/API/Interaction/ChatInteraction.php b/src/mibew/libs/classes/Mibew/API/Interaction/ChatInteraction.php
index 8b0a905a..13a41e11 100644
--- a/src/mibew/libs/classes/Mibew/API/Interaction/ChatInteraction.php
+++ b/src/mibew/libs/classes/Mibew/API/Interaction/ChatInteraction.php
@@ -20,7 +20,7 @@
namespace Mibew\API\Interaction;
/**
- * Implements Mibew Core - Mibew Chat Window interaction
+ * Implements Mibew Messenger Core - Mibew Messenger Chat Window interaction
*/
class ChatInteraction extends AbstractInteraction
{
diff --git a/src/mibew/libs/classes/Mibew/API/Interaction/UsersInteraction.php b/src/mibew/libs/classes/Mibew/API/Interaction/UsersInteraction.php
index 67699a32..5cf2d28e 100644
--- a/src/mibew/libs/classes/Mibew/API/Interaction/UsersInteraction.php
+++ b/src/mibew/libs/classes/Mibew/API/Interaction/UsersInteraction.php
@@ -20,7 +20,7 @@
namespace Mibew\API\Interaction;
/**
- * Implements Mibew Core - Mibew Users list interaction
+ * Implements Mibew Messenger Core - Mibew Messenger Users list interaction
*/
class UsersInteraction extends AbstractInteraction
{
diff --git a/src/mibew/libs/classes/Mibew/Button/Generator/ImageGenerator.php b/src/mibew/libs/classes/Mibew/Button/Generator/ImageGenerator.php
index 15eca059..34306430 100644
--- a/src/mibew/libs/classes/Mibew/Button/Generator/ImageGenerator.php
+++ b/src/mibew/libs/classes/Mibew/Button/Generator/ImageGenerator.php
@@ -66,7 +66,7 @@ class ImageGenerator extends TextGenerator
}
/**
- * Generates HTML markup for Mibew widget.
+ * Generates HTML markup for Mibew Messenger Widget.
*
* @return \Canteen\HTML5\Fragment
*/
diff --git a/src/mibew/libs/classes/Mibew/Controller/AbstractController.php b/src/mibew/libs/classes/Mibew/Controller/AbstractController.php
index 8cc813aa..959b0b3d 100644
--- a/src/mibew/libs/classes/Mibew/Controller/AbstractController.php
+++ b/src/mibew/libs/classes/Mibew/Controller/AbstractController.php
@@ -332,7 +332,7 @@ abstract class AbstractController implements
if ($style instanceof HandlebarsAwareInterface) {
$hbs = $style->getHandlebars();
- // Use mibew cache to store Handlebars AST
+ // Use Mibew Messenger cache to store Handlebars AST
$hbs->setCache(new HandlebarsCacheAdapter($this->getCache()));
// Add more helpers to template engine
diff --git a/src/mibew/libs/classes/Mibew/Controller/ButtonCodeController.php b/src/mibew/libs/classes/Mibew/Controller/ButtonCodeController.php
index d5a7f5f0..55ab2106 100644
--- a/src/mibew/libs/classes/Mibew/Controller/ButtonCodeController.php
+++ b/src/mibew/libs/classes/Mibew/Controller/ButtonCodeController.php
@@ -35,7 +35,7 @@ use Symfony\Component\HttpFoundation\Response;
class ButtonCodeController extends AbstractController
{
/**
- * Generates a page with Mibew button code form.
+ * Generates a page with Mibew Messenger button code form.
*
* @param Request $request Incoming request
* @return Response Rendered content of the page.
diff --git a/src/mibew/libs/classes/Mibew/Controller/Chat/AbstractController.php b/src/mibew/libs/classes/Mibew/Controller/Chat/AbstractController.php
index 5a579901..a6605308 100644
--- a/src/mibew/libs/classes/Mibew/Controller/Chat/AbstractController.php
+++ b/src/mibew/libs/classes/Mibew/Controller/Chat/AbstractController.php
@@ -77,8 +77,8 @@ abstract class AbstractController extends BaseAbstractController
* method accepts the following options:
* - "company": array, a set of company info. See {@link setup_logo()}
* for details.
- * - "mibewHost": string, a URL which is used as a Mibew host. See
- * {@link setup_logo()} for details.
+ * - "mibewHost": string, a URL which is used as a Mibew Messenger host.
+ * See {@link setup_logo()} for details.
* - "page.title": string, a value which will be used as a page title.
* - "startFrom": string, indicates what module should be invoked first.
* - "chatOptions": array, (optional) list of chat module options.
diff --git a/src/mibew/libs/classes/Mibew/Controller/InstallController.php b/src/mibew/libs/classes/Mibew/Controller/InstallController.php
index 223e50cb..9af1344e 100644
--- a/src/mibew/libs/classes/Mibew/Controller/InstallController.php
+++ b/src/mibew/libs/classes/Mibew/Controller/InstallController.php
@@ -51,7 +51,7 @@ class InstallController extends AbstractController
*/
public function indexAction(Request $request)
{
- // Check if Mibew is already installed.
+ // Check if Mibew Messenger is already installed.
$in_progress = !empty($_SESSION[SESSION_PREFIX . 'installation_in_progress']);
if (!$in_progress) {
if ($this->getInstaller()->isInstalled()) {
diff --git a/src/mibew/libs/classes/Mibew/Handlebars/CacheAdapter.php b/src/mibew/libs/classes/Mibew/Handlebars/CacheAdapter.php
index dfd9db61..eb436071 100644
--- a/src/mibew/libs/classes/Mibew/Handlebars/CacheAdapter.php
+++ b/src/mibew/libs/classes/Mibew/Handlebars/CacheAdapter.php
@@ -25,7 +25,7 @@ use Stash\Interfaces\PoolInterface;
use Stash\Invalidation;
/**
- * An adapter to use Mibew cache with Handlebars template engine.
+ * An adapter to use Mibew Messenger cache with Handlebars template engine.
*/
class CacheAdapter implements HandlebarsCacheInterface, CacheAwareInterface
{
diff --git a/src/mibew/libs/classes/Mibew/Maintenance/AvailableUpdate.php b/src/mibew/libs/classes/Mibew/Maintenance/AvailableUpdate.php
index c0a63496..c4ef94d8 100644
--- a/src/mibew/libs/classes/Mibew/Maintenance/AvailableUpdate.php
+++ b/src/mibew/libs/classes/Mibew/Maintenance/AvailableUpdate.php
@@ -27,7 +27,7 @@ use Mibew\Database;
class AvailableUpdate
{
/**
- * Unique (for the current Mibew instance) update ID.
+ * Unique (for the current Mibew Messenger instance) update ID.
*
* @type int
*/
diff --git a/src/mibew/libs/classes/Mibew/Maintenance/UpdateChecker.php b/src/mibew/libs/classes/Mibew/Maintenance/UpdateChecker.php
index 4e517bca..6cd6816c 100644
--- a/src/mibew/libs/classes/Mibew/Maintenance/UpdateChecker.php
+++ b/src/mibew/libs/classes/Mibew/Maintenance/UpdateChecker.php
@@ -35,7 +35,7 @@ class UpdateChecker
private $url = null;
/**
- * Unique 64 character length ID of the Mibew instance.
+ * Unique 64 character length ID of the Mibew Messenger instance.
*
* @var string
*/
@@ -80,7 +80,7 @@ class UpdateChecker
}
/**
- * Sets Unique ID of the Mibew instance.
+ * Sets Unique ID of the Mibew Messenger instance.
*
* @param string $id Unique ID that is 64 characters length at most.
* @throws \InvalidArgumentException
@@ -98,7 +98,7 @@ class UpdateChecker
}
/**
- * Retrieve Unique ID of the Mibew instance.
+ * Retrieve Unique ID of the Mibew Messenger instance.
*
* @return string
*/
diff --git a/src/mibew/libs/classes/Mibew/Maintenance/Updater.php b/src/mibew/libs/classes/Mibew/Maintenance/Updater.php
index 53f40881..e3548ece 100644
--- a/src/mibew/libs/classes/Mibew/Maintenance/Updater.php
+++ b/src/mibew/libs/classes/Mibew/Maintenance/Updater.php
@@ -28,7 +28,7 @@ use Stash\Interfaces\PoolInterface;
class Updater
{
/**
- * A minimum version Mibew can be updated from.
+ * A minimum version Mibew Messenger can be updated from.
*/
const MIN_VERSION = '2.0.0-beta.1';
@@ -201,7 +201,7 @@ class Updater
/**
* Gets version of existing database structure.
*
- * If Mibew is not installed yet boolean false will be returned.
+ * If Mibew Messenger is not installed yet boolean false will be returned.
*
* @return int|boolean Database structure version or boolean false if the
* version cannot be determined.
@@ -281,8 +281,9 @@ class Updater
array('return_rows' => Database::RETURN_ALL_ROWS)
);
- // Mibew base path should not be included in operators' avatars
- // which stored in the database. Remove the prefixes one by one.
+ // Mibew Messenger base path should not be included in operators'
+ // avatars which stored in the database. Remove the prefixes one
+ // by one.
foreach ($operators as $operator) {
if (empty($operator['avatar'])) {
// The operator has no avatar.
@@ -351,7 +352,7 @@ class Updater
. 'UNIQUE KEY target (target) '
. ') charset utf8 ENGINE=InnoDb');
- // Generate Unique ID of Mibew instance.
+ // Generate Unique ID of Mibew Messenger instance.
$db->query(
'INSERT INTO {config} (vckey, vcvalue) VALUES (:key, :value)',
array(
diff --git a/src/mibew/libs/classes/Mibew/Maintenance/Utils.php b/src/mibew/libs/classes/Mibew/Maintenance/Utils.php
index e026f687..480c8d56 100644
--- a/src/mibew/libs/classes/Mibew/Maintenance/Utils.php
+++ b/src/mibew/libs/classes/Mibew/Maintenance/Utils.php
@@ -102,7 +102,8 @@ class Utils
}
/**
- * Generates random unique 64 characters length ID for Mibew instance.
+ * Generates random unique 64 characters length ID for Mibew Messenger
+ * instance.
*
* WARNING: This ID should not be used for any security/cryptographic. If
* you need an ID for such purpose you have to use PHP's
diff --git a/src/mibew/libs/classes/Mibew/Plugin/PluginInterface.php b/src/mibew/libs/classes/Mibew/Plugin/PluginInterface.php
index ae56b339..5f1a6656 100644
--- a/src/mibew/libs/classes/Mibew/Plugin/PluginInterface.php
+++ b/src/mibew/libs/classes/Mibew/Plugin/PluginInterface.php
@@ -32,8 +32,8 @@ interface PluginInterface
public function getWeight();
/**
- * Builds base path for plugin files. This path is relative to Mibew root
- * and does not contain neither leading nor trailing slash.
+ * Builds base path for plugin files. This path is relative to Mibew
+ * Messenger root and does not contain neither leading nor trailing slash.
*
* @return string Base path for plugin files
*/
@@ -89,7 +89,7 @@ interface PluginInterface
* plugin version constrain.
*
* A requirement name can be on of the following:
- * - "mibew": Mibew core;
+ * - "mibew": Mibew Messenger Core;
* - "php": PHP used in the system;
* - "ext-*": name of a PHP extension.
*
diff --git a/src/mibew/libs/classes/Mibew/Plugin/Utils.php b/src/mibew/libs/classes/Mibew/Plugin/Utils.php
index 7326569a..df808113 100644
--- a/src/mibew/libs/classes/Mibew/Plugin/Utils.php
+++ b/src/mibew/libs/classes/Mibew/Plugin/Utils.php
@@ -125,7 +125,7 @@ class Utils
*
* @return array List of environment items. Each key is a string with one of
* the following value:
- * - "mibew": represents Mibew core;
+ * - "mibew": represents Mibew Messenger Core;
* - "php": represents PHP installed in the system;
* - "ext-*": represents one of PHP extensions.
* Each value of the array is version of the item.
diff --git a/src/mibew/libs/classes/Mibew/Style/ChatStyle.php b/src/mibew/libs/classes/Mibew/Style/ChatStyle.php
index 0b8ec26d..e9e37d07 100644
--- a/src/mibew/libs/classes/Mibew/Style/ChatStyle.php
+++ b/src/mibew/libs/classes/Mibew/Style/ChatStyle.php
@@ -28,8 +28,8 @@ use Mibew\Settings;
class ChatStyle extends AbstractHandlebarsPoweredStyle implements StyleInterface
{
/**
- * Builds base path for style files. This path is relative Mibew root and
- * does not contain neither leading nor trailing slash.
+ * Builds base path for style files. This path is relative Mibew Messenger
+ * root and does not contain neither leading nor trailing slash.
*
* @return string Base path for style files
*/
diff --git a/src/mibew/libs/classes/Mibew/Style/InvitationStyle.php b/src/mibew/libs/classes/Mibew/Style/InvitationStyle.php
index d39c1e61..6dff954b 100644
--- a/src/mibew/libs/classes/Mibew/Style/InvitationStyle.php
+++ b/src/mibew/libs/classes/Mibew/Style/InvitationStyle.php
@@ -28,8 +28,8 @@ use Mibew\Settings;
class InvitationStyle extends AbstractStyle implements StyleInterface
{
/**
- * Builds base path for style files. This path is relative Mibew root and
- * does not contain neither leading nor trailing slash.
+ * Builds base path for style files. This path is relative Mibew Messenger
+ * root and does not contain neither leading nor trailing slash.
*
* @return string Base path for style files
*/
diff --git a/src/mibew/libs/classes/Mibew/Style/PageStyle.php b/src/mibew/libs/classes/Mibew/Style/PageStyle.php
index b16206b4..4fb15c05 100644
--- a/src/mibew/libs/classes/Mibew/Style/PageStyle.php
+++ b/src/mibew/libs/classes/Mibew/Style/PageStyle.php
@@ -28,8 +28,8 @@ use Mibew\Settings;
class PageStyle extends AbstractHandlebarsPoweredStyle implements StyleInterface
{
/**
- * Builds base path for style files. This path is relative Mibew root and
- * does not contain neither leading nor trailing slash.
+ * Builds base path for style files. This path is relative Mibew Messenger
+ * root and does not contain neither leading nor trailing slash.
*
* @return string Base path for style files
*/
diff --git a/src/mibew/libs/classes/Mibew/Style/StyleInterface.php b/src/mibew/libs/classes/Mibew/Style/StyleInterface.php
index af280bcf..c8c1e964 100644
--- a/src/mibew/libs/classes/Mibew/Style/StyleInterface.php
+++ b/src/mibew/libs/classes/Mibew/Style/StyleInterface.php
@@ -57,8 +57,8 @@ interface StyleInterface
public static function getAvailableStyles();
/**
- * Builds base path for style files. This path is relative to Mibew root and
- * does not contain neither leading nor trailing slash.
+ * Builds base path for style files. This path is relative to Mibew
+ * Messenger root and does not contain neither leading nor trailing slash.
*
* @return string Base path for style files
*/
diff --git a/src/mibew/libs/common/constants.php b/src/mibew/libs/common/constants.php
index 2786974b..4009ced1 100644
--- a/src/mibew/libs/common/constants.php
+++ b/src/mibew/libs/common/constants.php
@@ -24,7 +24,7 @@ define('MIBEW_VERSION', '2.2.3');
/**
* Prefix for session variables.
- * Provide an ability to instal several mibew instances on one server.
+ * Provide an ability to instal several Mibew Messenger instances on one server.
*/
define('SESSION_PREFIX', md5(
$configs['database']['host'] . '##'
diff --git a/src/mibew/libs/init.php b/src/mibew/libs/init.php
index 61854527..63be017b 100644
--- a/src/mibew/libs/init.php
+++ b/src/mibew/libs/init.php
@@ -18,7 +18,7 @@
*/
/**
- * File system root directory of the Mibew installations
+ * File system root directory of the Mibew Messenger installations
*/
define('MIBEW_FS_ROOT', dirname(dirname(__FILE__)));
diff --git a/src/mibew/libs/operator.php b/src/mibew/libs/operator.php
index f16abcaf..43dae914 100644
--- a/src/mibew/libs/operator.php
+++ b/src/mibew/libs/operator.php
@@ -32,7 +32,7 @@ define('REMEMBER_OPERATOR_COOKIE_NAME', 'mibew_operator');
/** Permissions constants */
/**
- * Operator can administer Mibew instalation
+ * Operator can administer Mibew Messenger installation
*/
define('CAN_ADMINISTRATE', 0);
diff --git a/src/mibew/locales/en/mail_templates.yml b/src/mibew/locales/en/mail_templates.yml
index 649d5443..b3fa6871 100644
--- a/src/mibew/locales/en/mail_templates.yml
+++ b/src/mibew/locales/en/mail_templates.yml
@@ -1,9 +1,9 @@
user_history:
- subject: 'Mibew: dialog history'
- body: "Hello {0}!\n\nYour chat history: \n\n{1}\n--- \nRegards,\n{2} and Mibew\n{3}"
+ subject: 'Mibew Messenger: dialog history'
+ body: "Hello {0}!\n\nYour chat history: \n\n{1}\n--- \nRegards,\n{2} and Mibew Messenger\n{3}"
password_recovery:
- subject: 'Reset your Mibew password'
- body: "Hi, {0}\n\nPlease click on the link below or copy and paste the URL into your browser:\n{1}\n\nThis will let you choose another password.\n\nRegards,\nMibew"
+ subject: 'Reset your Mibew Messenger password'
+ body: "Hi, {0}\n\nPlease click on the link below or copy and paste the URL into your browser:\n{1}\n\nThis will let you choose another password.\n\nRegards,\nMibew Messenger"
leave_message:
subject: 'Question from {0}'
- body: "Your have a message from {0}:\n\n{2}\n\nHis email: {1}\n{3}\n--- \nRegards,\nMibew"
+ body: "Your have a message from {0}:\n\n{2}\n\nHis email: {1}\n{3}\n--- \nRegards,\nMibew Messenger"
diff --git a/src/mibew/locales/en/translation.po b/src/mibew/locales/en/translation.po
index 03ef1b96..e5fae91b 100644
--- a/src/mibew/locales/en/translation.po
+++ b/src/mibew/locales/en/translation.po
@@ -1 +1 @@
-# This file is empty because english strings are a part of Mibew core
\ No newline at end of file
+# This file is empty because english strings are a part of Mibew Messenger core
\ No newline at end of file
diff --git a/src/mibew/styles/chats/default/templates_src/client_side/chat/layout.handlebars b/src/mibew/styles/chats/default/templates_src/client_side/chat/layout.handlebars
index ded83549..56f964b5 100644
--- a/src/mibew/styles/chats/default/templates_src/client_side/chat/layout.handlebars
+++ b/src/mibew/styles/chats/default/templates_src/client_side/chat/layout.handlebars
@@ -26,4 +26,4 @@
{{! Footer links}}
-
\ No newline at end of file
+
\ No newline at end of file
diff --git a/src/mibew/libs/classes/Mibew/Maintenance/Installer.php b/src/mibew/libs/classes/Mibew/Maintenance/Installer.php
index 9b56b19c..064cac4e 100644
--- a/src/mibew/libs/classes/Mibew/Maintenance/Installer.php
+++ b/src/mibew/libs/classes/Mibew/Maintenance/Installer.php
@@ -28,7 +28,7 @@ use Symfony\Component\Yaml\Parser as YamlParser;
class Installer
{
/**
* Minimal PHP version Mibew works with.
*/
const MIN_PHP_VERSION = 50303;
@@ -92,7 +92,7 @@ class Installer
}
/**
* Checks if Mibew is already installed or not.
*
* @return boolean
*/
@@ -440,7 +440,7 @@ class Installer
return false;
}
// Generate Unique ID for Mibew Instance
try {
list($count) = $db->query(
'SELECT COUNT(*) FROM {config} WHERE vckey = :key',
@@ -508,7 +508,7 @@ class Installer
if ($current_version < self::MIN_PHP_VERSION) {
$this->errors[] = getlocal(
- "PHP version is {0}, but Mibew works with {1} and later versions.",
+ "PHP version is {0}, but Mibew Messenger works with {1} and later versions.",
array(
Utils::formatVersionId($current_version),
Utils::formatVersionId(self::MIN_PHP_VERSION)
@@ -627,7 +627,7 @@ class Installer
/**
* Gets version of existing database structure.
*
* If Mibew is not installed yet boolean false will be returned.
*
* @return string|boolean Database structure version or boolean false if the
* version cannot be determined.
@@ -28,7 +28,7 @@ use Symfony\Component\Yaml\Parser as YamlParser;
{
/**
- * Minimal PHP version Mibew works with.
+ * Minimal PHP version Mibew Messenger works with.
*/
const MIN_PHP_VERSION = 50303;
@@ -92,7 +92,7 @@ class Installer
}
/**
- * Checks if Mibew is already installed or not.
+ * Checks if Mibew Messenger is already installed or not.
*
* @return boolean
@@ -440,7 +440,7 @@ class Installer
return false;
}
- // Generate Unique ID for Mibew Instance
+ // Generate Unique ID for Mibew Messenger Instance
try {
list($count) = $db->query(
@@ -627,7 +627,7 @@ class Installer
* Gets version of existing database structure.
*
- * If Mibew is not installed yet boolean false will be returned.
+ * If Mibew Messenger is not installed yet boolean false will be returned.
*
* @return string|boolean Database structure version or boolean false if the